#!/bin/bash
# This script executes some manual tasks following the installation of a Drupal platform.

#****************************************
# Variables
#****************************************

EXIT_NB=0
THIS_FILE=$(echo $0 | awk -F/ '{print $NF}')
PATH_PLATFORM=$1
DRUPAL_VERSION=6   # Drupal version for which the script is designed.
WWW_DATA=www-data  # use www-data for debian & ubuntu, apache for redhat & centos

# use www-data for debian & ubuntu; apache for redhat & centos
# TODO add test for RedHat
WWW_DATA=www-data
if [ -x /usr/bin/lsb_release ]; then
  DISTRO=$(lsb_release -i | cut -f 2)
  if [ "$DISTRO" = "CentOS" ]; then
    WWW_DATA=apache
  fi
fi

#****************************************
# Verifications
#****************************************

case $PATH_PLATFORM in

  # Check if the directory passed as argument is absolute.
  /*)
    # Check if the directory passed as argument does not exist.
    if [ ! -d $PATH_PLATFORM ]; then
      echo
      echo "ERROR: Directory '$PATH_PLATFORM' does not exist."
      echo
      exit 1
    fi
  ;;

  *)
    echo
    echo "ERROR: Directory is missing or is not absolute."
    echo
    echo Usage:
    echo "$THIS_FILE /absolute/path/to/the/platform"
    echo
    exit 1
  ;;

esac

# Check if the platform directory contains the file CHANGELOG.txt
if [ ! -f $PATH_PLATFORM/CHANGELOG.txt ]; then
  echo
  echo "ERROR: Directory '$PATH_PLATFORM' does not contain the file CHANGELOG.txt."
  echo
  exit 1
fi

# Check if the version of Drupal is the one the script is for.
DRUPAL_VERSION_PLATFORM=$(head -n1 $PATH_PLATFORM/CHANGELOG.txt | tail -n1 | awk -F. '{print $1}' | awk '{print $NF}')
if [ "$DRUPAL_VERSION_PLATFORM" != "$DRUPAL_VERSION" ]; then
  echo
  echo "ERROR: The version of Drupal installed in the platform is not the same as the script is expecting."
  echo
  exit 1
fi

#****************************************
# Patching librairies
#****************************************

# TCPDF for the Drupal contrib module "Printer, e-mail and PDF versions" (print).
# TCPDF directories non-writable permissions.
chmod g+w $PATH_PLATFORM/sites/all/libraries/tcpdf/cache $PATH_PLATFORM/sites/all/libraries/tcpdf/images && \
  chgrp $WWW_DATA $PATH_PLATFORM/sites/all/libraries/tcpdf/cache $PATH_PLATFORM/sites/all/libraries/tcpdf/images
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: TCPDF chmod and chgrp."
else
  echo "ERROR: TCPDF chmod and chgrp."
  EXIT_NB=1
fi

#****************************************
# Conclusion
#****************************************

if [ $EXIT_NB -eq 0 ]; then
  echo "OK: '$THIS_FILE' terminated successfully."
  exit $EXIT_NB
else
  echo "ERROR: '$THIS_FILE' terminated with error(s)."
  exit $EXIT_NB
fi

#****************************************
# End
#****************************************
